@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,14 +16,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include"cxpre.h"		/* Automatically includes "xpre.h" */
 
-extern int x_sgn (struct xpr x);	/* see constant.c */
-
 struct cxpr
 cxadd (struct cxpr z1, struct cxpr z2, int k)
 {
@@ -139,7 +137,7 @@ cxsqrt (struct cxpr z)
   struct xpr mod, arg;
   struct cxpr w;
 
-  if (x_sgn (z.re) == 0 && x_sgn (z.im) == 0)
+  if (xsgn (&z.re) == 0 && xsgn (&z.im) == 0)
     return cxZero;
   else
     {
