@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,14 +16,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include"cxpre.h"		/* Automatically includes "xpre.h" */
 
-extern int x_sgn (struct xpr x);	/* see constant.c */
-
 struct cxpr
 cxreset (struct xpr re, struct xpr im)
 {
@@ -108,8 +106,8 @@ cxarg (struct cxpr z)
 {
   int rs, is;
 
-  rs = x_sgn (z.re);
-  is = x_sgn (z.im);
+  rs = xsgn (&z.re);
+  is = xsgn (&z.im);
   if (rs > 0)
     return xatan (xdiv (z.im, z.re));
   else if (rs < 0)
