@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,14 +16,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include"cxpre.h"		/* Automatically includes "xpre.h" */
 
-extern int x_sgn (struct xpr x);	/* see constant.c */
-
 struct cxpr
 cxexp (struct cxpr z)
 {
@@ -63,7 +61,7 @@ cxlog (struct cxpr z)
   struct cxpr w;
 
   mod = cxabs (z);
-  if (xsigerr (x_sgn (mod) <= 0, XEDOM, "cxlog()"))
+  if (xsigerr (xsgn (&mod) <= 0, XEDOM, "cxlog()"))
     return cxZero;
   else
     {
@@ -80,7 +78,7 @@ cxlog10 (struct cxpr z)
   struct cxpr w;
 
   mod = cxabs (z);
-  if (xsigerr (x_sgn (mod) <= 0, XEDOM, "cxlog10()"))
+  if (xsigerr (xsgn (&mod) <= 0, XEDOM, "cxlog10()"))
     return cxZero;
   else
     {
@@ -97,7 +95,7 @@ cxlog2 (struct cxpr z)
   struct cxpr w;
 
   mod = cxabs (z);
-  if (xsigerr (x_sgn (mod) <= 0, XEDOM, "cxlog2()"))
+  if (xsigerr (xsgn (&mod) <= 0, XEDOM, "cxlog2()"))
     return cxZero;
   else
     {
@@ -114,7 +112,7 @@ cxlog_sqrt (struct cxpr z)
   struct cxpr w;
 
   mod = cxabs (z);
-  if (xsigerr (x_sgn (mod) <= 0, XEDOM, "cxlog_sqrt()"))
+  if (xsigerr (xsgn (&mod) <= 0, XEDOM, "cxlog_sqrt()"))
     return cxZero;
   else
     {
