@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,14 +16,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include"cxpre.h"		/* Automatically includes "xpre.h" */
 
-extern int x_sgn (struct xpr x);	/* see constant.c */
-
 struct cxpr
 cxsinh (struct cxpr z)
 {
@@ -100,9 +98,11 @@ struct cxpr
 cxatanh (struct cxpr z)
 {
   struct cxpr w;
+  struct xpr t;
   int errcond;
 
-  errcond = x_sgn (z.im) == 0 && x_sgn (xadd (xabs (z.re), xOne, 1)) == 0;
+  t = xadd (xabs (z.re), xOne, 1);
+  errcond = xsgn (&z.im) == 0 && xsgn (&t) == 0;
   if (xsigerr (errcond, XEDOM, "cxatanh()"))
     return cxZero;
   else
