@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,14 +16,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include"cxpre.h"		/* Automatically includes "xpre.h" */
 
-extern int x_sgn (struct xpr x);	/* see constant.c */
-
 struct cxpr
 cxgdiv (struct cxpr z1, struct cxpr z2)
 {
@@ -35,7 +33,7 @@ cxgdiv (struct cxpr z1, struct cxpr z2)
   z2.im = xround (z2.im);
   mod2 = xadd (xmul (z2.re, z2.re), xmul (z2.im, z2.im), 0);
   if (xsigerr (xprcmp (&mod2, &xPinf) >= 0, XFPOFLOW, NULL) ||
-      xsigerr (x_sgn (mod2) <= 0, XEDIV, "cxgdiv()"))
+      xsigerr (xsgn (&mod2) <= 0, XEDIV, "cxgdiv()"))
     return cxZero;
   else
     {
@@ -60,7 +58,7 @@ cxidiv (struct cxpr z1, struct cxpr z2)
   z2.im = xround (z2.im);
   mod2 = xadd (xmul (z2.re, z2.re), xmul (z2.im, z2.im), 0);
   if (xsigerr (xprcmp (&mod2, &xPinf) >= 0, XFPOFLOW, NULL) ||
-      xsigerr (x_sgn (mod2) <= 0, XEDIV, "cxidiv()"))
+      xsigerr (xsgn (&mod2) <= 0, XEDIV, "cxidiv()"))
     return cxZero;
   else
     {
@@ -85,7 +83,7 @@ cxgmod (struct cxpr z1, struct cxpr z2)
   z2.im = xround (z2.im);
   mod2 = xadd (xmul (z2.re, z2.re), xmul (z2.im, z2.im), 0);
   if (xsigerr (xprcmp (&mod2, &xPinf) >= 0, XFPOFLOW, NULL) ||
-      xsigerr (x_sgn (mod2) <= 0, XEDIV, "cxgmod()"))
+      xsigerr (xsgn (&mod2) <= 0, XEDIV, "cxgmod()"))
     return cxZero;
   else
     {
@@ -114,7 +112,7 @@ cxmod (struct cxpr z1, struct cxpr z2)
   z2.im = xround (z2.im);
   mod2 = xadd (xmul (z2.re, z2.re), xmul (z2.im, z2.im), 0);
   if (xsigerr (xprcmp (&mod2, &xPinf) >= 0, XFPOFLOW, NULL) ||
-      xsigerr (x_sgn (mod2) <= 0, XEDIV, "cxmod()"))
+      xsigerr (xsgn (&mod2) <= 0, XEDIV, "cxmod()"))
     return cxZero;
   else
     {
