@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,14 +16,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include"cxpre.h"		/* Automatically includes "xpre.h" */
 
-extern int x_sgn (struct xpr x);	/* see constant.c */
-
 static void
 unit_root (int i, int n, struct xpr *a, struct xpr *b)
 {
@@ -47,7 +45,7 @@ cxpwr (struct cxpr z, int n)
   struct cxpr w;
 
   mod = cxabs (z);
-  if (x_sgn (mod) <= 0)
+  if (xsgn (&mod) <= 0)
     {
       int dummy;
 
@@ -76,7 +74,7 @@ cxroot (struct cxpr z, int i, int n)
   else
     {
       mod = cxabs (z);
-      if (x_sgn (mod) <= 0)
+      if (xsgn (&mod) <= 0)
 	{
 	  int dummy;
 
@@ -106,11 +104,11 @@ cxpow (struct cxpr z1, struct cxpr z2)
   struct cxpr w;
 
   mod = cxabs (z1);
-  if (x_sgn (mod) <= 0)
+  if (xsgn (&mod) <= 0)
     {
       int dummy;
 
-      dummy = xsigerr (x_sgn (z2.re) <= 0, XEBADEXP, "cxpow()");
+      dummy = xsigerr (xsgn (&z2.re) <= 0, XEBADEXP, "cxpow()");
       return cxZero;
     }
   else
