@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include"cxpre.h"		/* Automatically includes "xpre.h" */
@@ -33,15 +33,15 @@ cxprcmp (const struct cxpr* z1, const struct cxpr* z2)
 }
 
 int
-cxis0 (struct cxpr z)
+cxis0 (const struct cxpr* z)
 {
-  return (xprcmp (&z.re, &xZero) == 0 && xprcmp (&z.im, &xZero) == 0);
+  return (xis0 (&z->re) && xis0 (&z->im));
 }
 
 int
-cxnot0 (struct cxpr z)
+cxnot0 (const struct cxpr* z)
 {
-  return (xprcmp (&z.re, &xZero) != 0 || xprcmp (&z.im, &xZero) != 0);
+  return (xnot0 (&z->re) || xnot0 (&z->im));
 }
 
 int
