@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #ifndef _CXPRE_H_
@@ -80,8 +80,8 @@ extern "C"
   struct cxpr cxsqrt (struct cxpr z);
 
   struct cxprcmp_res cxprcmp (const struct cxpr* z1, const struct cxpr* z2);
-  int cxis0 (struct cxpr z);
-  int cxnot0 (struct cxpr z);
+  int cxis0 (const struct cxpr* z);
+  int cxnot0 (const struct cxpr* z);
   int cxeq (struct cxpr z1, struct cxpr z2);
   int cxneq (struct cxpr z1, struct cxpr z2);
   int cxgt (struct cxpr z1, struct cxpr z2);
