@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include<stdio.h>
@@ -35,6 +35,15 @@ xfileputc (int c, FILE * stream)
     }
 }
 
+void
+xstrputc (char c, char* buffer)
+{
+  register char *ptr;
+
+  for (ptr = buffer; *ptr != '\0'; ptr++);
+  *ptr = c;
+}
+
 void
 xprintfmt (FILE * stream, const char *fmt, ...)
 {
@@ -67,7 +76,7 @@ int
 xwprint (const char *buff, short mfwd, char padding, FILE * fp)
 {
   unsigned short length = strlen (buff);
-  long i;
+  register long i;
 
   if (!buff || !fp)
     return -1;
@@ -99,7 +108,7 @@ void
 xwsprint (char *dest, const char *src, short mfwd, char padding)
 {
   unsigned short length = strlen (src);
-  long i;
+  register long i;
 
   if (!dest || !src)
     return;
@@ -124,7 +133,7 @@ xwsnprint (char *dest, size_t dsize, const char *src,
 	   short mfwd, char padding)
 {
   unsigned short n = strlen (src);
-  long i;
+  register long i;
 
   if (dsize == 0 || !dest || !src)
     return 0;
