@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include "xpre.h"
@@ -41,7 +41,7 @@ xabs (struct xpr s)
 }
 
 int
-x_exp (struct xpr *ps)
+x_exp (const struct xpr *ps)
 {
   unsigned short *q = (unsigned short *) ps;
 
@@ -49,7 +49,7 @@ x_exp (struct xpr *ps)
 }
 
 int
-x_neg (struct xpr *ps)
+x_neg (const struct xpr *ps)
 {
   unsigned short *q = (unsigned short *) ps;
 
