@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 #include "xpre.h"
@@ -31,8 +31,8 @@
 int
 xprcmp (const struct xpr *pa, const struct xpr *pb)
 {
-  unsigned short e, k, *p, *q, p0, q0;
-  int m;
+  register unsigned short e, k, *p, *q, p0, q0;
+  register int m;
 
   p = (unsigned short *) pa;
   q = (unsigned short *) pb;
@@ -74,18 +74,6 @@ xprcmp (const struct xpr *pa, const struct xpr *pb)
     }
 }
 
-int
-xis0 (struct xpr x)
-{
-  return (xprcmp (&x, &xZero) == 0);
-}
-
-int
-xnot0 (struct xpr x)
-{
-  return (xprcmp (&x, &xZero) != 0);
-}
-
 int
 xeq (struct xpr x1, struct xpr x2)
 {
@@ -123,21 +111,85 @@ xle (struct xpr x1, struct xpr x2)
 }
 
 /*
-  xisNaN (&x) returns 1 if and only if x == xNaN
+  xisNaN (&x) returns 1 if and only if x is not a valid number
 */
 
 int
 xisNaN (const struct xpr *u)
 {
-  unsigned short* p = (unsigned short *) u;
+  register unsigned short* p = (unsigned short *) u;
 
-  if (*p != 0x0)
+  if ((*p))
     return 0;
   else
     {
-      int i;
+      register int i;
 
-      for (i=1; i <= XDIM && p[i] == 0xffff; i++);
-      return (i > XDIM ? 1 : 0);
+      for (i=1; i <= XDIM && p[i] == 0x0; i++);
+      return (i <= XDIM ? 1 : 0);
     }
 }
+
+int
+xis0 (const struct xpr *u)
+{
+  register unsigned short* p = (unsigned short *) u;
+  register int m;
+
+  for (m = 1; m <= XDIM && p[m] == 0; m++);
+  return (m > XDIM && (*p & xM_exp) < xM_exp ? 1 : 0);
+}
+
+int
+xnot0 (const struct xpr *u)
+{
+  register unsigned short* p = (unsigned short *) u;
+  register int m;
+
+  for (m = 1; m <= XDIM && p[m] == 0; m++);
+  return (m > XDIM && (*p & xM_exp) < xM_exp ? 0 : 1);
+}
+
+int
+xsgn (const struct xpr *u)
+{
+  register unsigned short* p = (unsigned short *) u;
+  register int m;
+
+  for (m = 1; m <= XDIM && p[m] == 0; m++);
+  if ((m > XDIM && (*p & xM_exp) < xM_exp) || !*p)
+    return 0;
+  else
+    return ((*p & xM_sgn) ? -1 : 1);
+}
+
+int
+xisPinf (const struct xpr *u)
+{
+  return (*u->nmm == xM_exp ? 1 : 0);
+}
+
+int
+xisMinf (const struct xpr *u)
+{
+  return (*u->nmm == (xM_exp | xM_sgn) ? 1 : 0);
+}
+
+int
+xisordnumb (const struct xpr *u)
+{
+  int isNaN, isfinite;
+  register unsigned short* p = (unsigned short *) u;
+
+  if ((*p))
+    isNaN = 0;
+  else
+    {
+      register int i;
+
+      for (i=1; i <= XDIM && p[i] == 0x0; i++);
+      isNaN = i <= XDIM;
+    }
+  isfinite = (*p & xM_exp) < xM_exp;
+  return (!isNaN && (isfinite) ? 1 : 0);
+}
