@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 /*
@@ -330,7 +330,7 @@ Test of cxarg
  cxarg(z) = 	*** Out of domain
 *string in : 	+2.3106e-1571
  z =  		2.31059999999999999999999999999571e-1571  	0.00000000000000000000000000000000e+0
- cxarg(z) = 	0.00000000000000000000000000000000e-3362
+ cxarg(z) = 	0.00000000000000000000000000000000e+0
 *string in : 	+8.7792e-20  +9.7732e-20i
  z =  		8.77919999999999999999999999999979e-20  	9.77319999999999999999999999999977e-20
  cxarg(z) = 	8.38924958292089629849736401676606e-1
