@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 /*
@@ -86,13 +86,13 @@ main (int na, char **av)
       printf ("\nz2 = ");
       cxpr_print (stdout, z2, 0, 1, DECD);
       putchar ('\n');
-      if ((cxis0 (z1)))
+      if ((cxis0 (&z1)))
 	printf ("z1 == 0 \t");
-      if ((cxis0 (z2)))
+      if ((cxis0 (&z2)))
 	printf ("z2 == 0 \t");
-      if ((cxnot0 (z1)))
+      if ((cxnot0 (&z1)))
 	printf ("z1 != 0 \t");
-      if ((cxnot0 (z2)))
+      if ((cxnot0 (&z2)))
 	printf ("z2 != 0 \t");
       for (i = 0; nlist[i] != NULL; i++)
 	{
