@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 /*
@@ -248,11 +248,11 @@ Test of cxpwr()
 *string in : 	-7.772     +0.0i		 2
  z =  		-7.77200000000000000000000000000000e+0  	0.00000000000000000000000000000000e+0
  n = 2
- cxpwr(z,n) = 	6.04039839999999999999999999999999e+1  	0.00000000000000000000000000000000e-4931
+ cxpwr(z,n) = 	6.04039839999999999999999999999999e+1  	0.00000000000000000000000000000000e+0
 *string in : 	-7.772     +0.0i		 3
  z =  		-7.77200000000000000000000000000000e+0  	0.00000000000000000000000000000000e+0
  n = 3
- cxpwr(z,n) = 	-4.69459763647999999999999999999998e+2  	0.00000000000000000000000000000000e-4930
+ cxpwr(z,n) = 	-4.69459763647999999999999999999998e+2  	0.00000000000000000000000000000000e+0
 *string in : 	-7.772     +0.0i		-5
  z =  		-7.77200000000000000000000000000000e+0  	0.00000000000000000000000000000000e+0
  n = -5
@@ -264,7 +264,7 @@ Test of cxpwr()
 *string in : 	+82.06126  +0i			 7
  z =  		8.20612599999999999999999999999998e+1  	0.00000000000000000000000000000000e+0
  n = 7
- cxpwr(z,n) = 	2.50592037363291607837155265799731e+13  	0.00000000000000000000000000000000e-4919
+ cxpwr(z,n) = 	2.50592037363291607837155265799731e+13  	0.00000000000000000000000000000000e+0
 *string in : 	-88.7665   -7.432i		-4
  z =  		-8.87664999999999999999999999999998e+1  	-7.43200000000000000000000000000000e+0
  n = -4
@@ -296,7 +296,7 @@ Test of cxpwr()
 *string in : 	8765.9431      +0i		 5
  z =  		8.76594309999999999999999999999996e+3  	0.00000000000000000000000000000000e+0
  n = 5
- cxpwr(z,n) = 	5.17598771096611818114274172099114e+19  	0.00000000000000000000000000000000e-4913
+ cxpwr(z,n) = 	5.17598771096611818114274172099114e+19  	0.00000000000000000000000000000000e+0
 *string in : 	8999.432192e+8 +3.042e+12i	 1
  z =  		8.99943219199999999999999999999988e+11  	3.04199999999999999999999999999996e+12
  n = 1
@@ -316,7 +316,7 @@ Test of cxpwr()
 *string in : 	0  +6.7891e+24i		 	 4
  z =  		0.00000000000000000000000000000000e+0  	6.78909999999999999999999999999981e+24
  n = 4
- cxpwr(z,n) = 	2.12446129223572701609999999999976e+99  	0.00000000000000000000000000000000e-4833
+ cxpwr(z,n) = 	2.12446129223572701609999999999976e+99  	0.00000000000000000000000000000000e+0
 *string in : 	0  +6.7891e+24i			-5
  z =  		0.00000000000000000000000000000000e+0  	6.78909999999999999999999999999981e+24
  n = -5
@@ -336,7 +336,7 @@ Test of cxpwr()
 *string in : 	0		-8.88165e+152i	+8
  z =  		0.00000000000000000000000000000000e+0  	-8.88164999999999999999999999999840e+152
  n = 8
- cxpwr(z,n) = 	3.87212384426447405346650496980991e+1223  	-0.00000000000000000000000000000000e-3709
+ cxpwr(z,n) = 	3.87212384426447405346650496980991e+1223  	-0.00000000000000000000000000000000e+0
 *string in : 	0		-8.88165e+152i	-9
  z =  		0.00000000000000000000000000000000e+0  	-8.88164999999999999999999999999840e+152
  n = -9
@@ -505,7 +505,7 @@ Test of cxroot()
  z =  		-7.77200000000000000000000000000000e+0  	0.00000000000000000000000000000000e+0
  n = 2
  cxroot(z,0,n) = 	0.00000000000000000000000000000000e+0  	2.78783069787245150781099035414601e+0
- cxroot(z,1,n) = 	-0.00000000000000000000000000000000e-4932  	-2.78783069787245150781099035414601e+0
+ cxroot(z,1,n) = 	-0.00000000000000000000000000000000e+0  	-2.78783069787245150781099035414601e+0
  cxroot(z,2,n) = 	0.00000000000000000000000000000000e+0  	2.78783069787245150781099035414601e+0
 *string in : 	-7.772     +0.0i		 3
  z =  		-7.77200000000000000000000000000000e+0  	0.00000000000000000000000000000000e+0
@@ -592,12 +592,12 @@ Test of cxroot()
 *string in : 	8765.9431      +0i		 5
  z =  		8.76594309999999999999999999999996e+3  	0.00000000000000000000000000000000e+0
  n = 5
- cxroot(z,0,n) = 	6.14553546775590737887926824134809e+0  	0.00000000000000000000000000000000e-4932
+ cxroot(z,0,n) = 	6.14553546775590737887926824134809e+0  	0.00000000000000000000000000000000e+0
  cxroot(z,1,n) = 	1.89907489907056711732805091676940e+0  	5.84475155273224035605203777834818e+0
  cxroot(z,2,n) = 	-4.97184263294852080676768503744344e+0  	3.61225511538724788185504742800745e+0
  cxroot(z,3,n) = 	-4.97184263294852080676768503744346e+0  	-3.61225511538724788185504742800740e+0
  cxroot(z,4,n) = 	1.89907489907056711732805091676936e+0  	-5.84475155273224035605203777834820e+0
- cxroot(z,5,n) = 	6.14553546775590737887926824134809e+0  	0.00000000000000000000000000000000e-4932
+ cxroot(z,5,n) = 	6.14553546775590737887926824134809e+0  	0.00000000000000000000000000000000e+0
 *string in : 	8999.432192e+8 +3.042e+12i	 1
  z =  		8.99943219199999999999999999999988e+11  	3.04199999999999999999999999999996e+12
  n = 1
