@@ -1,6 +1,6 @@
 /*
    Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
-   Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
+   Copyright (C)  2004    Ivano Primi  <ivprimi@libero.it>    
 
    This file is part of the HPA Library.
 
@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the HPA Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.
+   Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+   02110-1301 USA.
 */
 
 /*
@@ -550,25 +550,25 @@ main (int na, char **av)
  OVERFLOW
 *string in : "-8.66E-5000"
  endptr   : ""
- z =       -0.000000000000000000000000000000e-4931+0.000000000000000000000000000000e+0i
+ z =       -0.000000000000000000000000000000e+0+0.000000000000000000000000000000e+0i
 *string in : "+7.55E+5000 +7i"
  endptr   : ""
  OVERFLOW
 *string in : "-8.66e-5000  -65i"
  endptr   : ""
- z =       -0.000000000000000000000000000000e-4931-6.500000000000000000000000000000e+1i
+ z =       -0.000000000000000000000000000000e+0-6.500000000000000000000000000000e+1i
 *string in : "8.355e5400i"
  endptr   : ""
  OVERFLOW
 *string in : "-2.66E-5800i"
  endptr   : ""
- z =       +0.000000000000000000000000000000e+0-0.000000000000000000000000000000e-4931i
+ z =       +0.000000000000000000000000000000e+0-0.000000000000000000000000000000e+0i
 *string in : "67   +8.355e+5400i"
  endptr   : ""
  OVERFLOW
 *string in : "-654 -2.66E-5800i"
  endptr   : ""
- z =       -6.540000000000000000000000000000e+2-0.000000000000000000000000000000e-4931i
+ z =       -6.540000000000000000000000000000e+2-0.000000000000000000000000000000e+0i
 *string in : "64.32e5400 +45.322e+5100i"
  endptr   : ""
  OVERFLOW
@@ -589,10 +589,10 @@ main (int na, char **av)
  OVERFLOW
 *string in : "-64.32e-5400 -45.322e-5100i"
  endptr   : ""
- z =       -0.000000000000000000000000000000e-4931-0.000000000000000000000000000000e-4930i
+ z =       -0.000000000000000000000000000000e+0-0.000000000000000000000000000000e+0i
 *string in : "+64.32E-5400 -45.322E-5100i"
  endptr   : ""
- z =       +0.000000000000000000000000000000e-4931-0.000000000000000000000000000000e-4930i
+ z =       +0.000000000000000000000000000000e+0-0.000000000000000000000000000000e+0i
 *string in : "!!End!!"
  endptr   : "!!End!!"
  NAN
